# PromptizeThis

Converts your local codebase (and other files) to a prompt to copy-paste 

## Installation

You can install PromptizeThis directly from PyPI:

```bash
pip install PromptizeThis
```

## Usage

```bash
PromptizeThis ./
```

![Demo](static/demo.png)





